# feather_creator

Allows creation of .feather file to use in the pyscenic pipeline from motifs and gene sequences.

### Dependencies

+ `pip install numpy` version 1.19.5
+ `pip install biopython` version 1.73
+ `pip install pyarrow` version 0.16.0
+ `pip install pandas`
+ `pip install tqdm` 

using pip environment
+ `python3 -m venv feather_creator_env`
+ `source feather_creator_env/bin/activate`
+ `python3 -m pip install -r requirements.txt`

### Installation:

TODO : ajouter sur pypi
`pip install feather_creator`

### Tutorials:



### Material

This module relies on the `iRegulon` dataset, which has also been used for `i-cistarget`.

   http://iregulon.aertslab.org/collections.html#motifcolldownload

Direct download link for the motif collection:

   https://resources.aertslab.org/papers/iregulon/motifColl-10k-all-public.tar.gz

(Janky and Verfaillie et al., PLoS Comp Biol 2014) 

Necessary motif-TF association file:

   https://resources.aertslab.org/cistarget/motif2tf/

